"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const splitAction_1 = require("./splitAction");
const actionsData = require('../actions.json');
buildDataActions();
const DefaultActions = actionsData.actions.map(item => item.action);
const LanguageActions = Object.keys(actionsData.languages)
    .reduce((data, lang) => {
    data.set(lang, actionsData.languages[lang].actions.map(item => item.action));
    return data;
}, new Map());
const LanguageCountryActions = Object.keys(actionsData.languages)
    .reduce((data, lang) => {
    Object.keys(actionsData.languages[lang].countries)
        .reduce((_, country) => {
        data.set(`${lang}-${country}`, actionsData.languages[lang].countries[country].actions.map(item => item.action));
        return data;
    }, data);
    return data;
}, new Map());
function getActions(lang, country) {
    if (typeof lang === 'string') {
        if (typeof country === 'string') {
            return LanguageCountryActions.get(`${lang}-${country}`);
        }
        return LanguageActions.get(lang);
    }
    return DefaultActions;
}
exports.getActions = getActions;
function getActionsData() {
    return actionsData;
}
exports.getActionsData = getActionsData;
function buildDataActions() {
    actionsData.actions = actionsData.actions || [];
    actionsData.actions.forEach(info => info.action = buildAction(info));
    for (let lang of Object.keys(actionsData.languages)) {
        const langInfo = actionsData.languages[lang];
        const langInherit = langInfo.inherit;
        langInfo.actions = langInfo.actions || [];
        langInfo.actions.forEach(info => info.action = buildAction(info));
        if (langInherit === true) {
            langInfo.actions = actionsData.actions.concat(langInfo.actions);
        }
        for (let country of Object.keys(langInfo.countries)) {
            const countryInfo = langInfo.countries[country];
            const countryInherit = countryInfo.inherit;
            countryInfo.actions = countryInfo.actions || [];
            countryInfo.actions.forEach(info => info.action = buildAction(info));
            if (countryInherit === true) {
                countryInfo.actions = langInfo.actions.concat(countryInfo.actions);
            }
        }
    }
}
function buildAction(info) {
    switch (info.type) {
        case 'prefix':
            return splitAction_1.createPrefixAction(new RegExp(info.value, 'i'));
        default: throw new Error(`Invalid action type: ${info.type}`);
    }
}
