"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const debug = require('debug')('partial-name');
const action_1 = require("./action");
function createSplitAction(splitter, options) {
    const joiner = options.joiner;
    const stopOnSuccess = options.stopOnSuccess;
    return (name) => {
        const parts = name.split(splitter);
        if (parts.length < 2) {
            return { success: false, name: null };
        }
        const partialName = joiner(parts);
        if (!action_1.isValidName(partialName)) {
            debug(`split partial name is invalid: ${partialName}`);
            return { success: false, name: null };
        }
        return { stopOnSuccess, success: true, name: partialName };
    };
}
exports.createSplitAction = createSplitAction;
function createPrefixAction(splitter) {
    return createSplitAction(splitter, { joiner: (parts) => parts[0] });
}
exports.createPrefixAction = createPrefixAction;
function createSuffixAction(splitter) {
    return createSplitAction(splitter, { joiner: (parts) => parts[parts.length - 1] });
}
exports.createSuffixAction = createSuffixAction;
